==> 3.5.12-core.tar: kdemultimedia/kmid/qslidertime.h <==
/**************************************************************************

    kslidertime.h  - A widget that displays time tags under a KSlider
    Copyright (C) 1997,98  Antonio Larrosa Jimenez

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

    Send comments and bug fixes to larrosa@kde.org
    or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain

***************************************************************************/
#ifndef _kslidertime_h_
#define _kslidertime_h_

#include <tqslider.h>

class TQWidget;

class QSliderTime : public QWidget
{
  Q_OBJECT
private:

  TQSlider *kslider;

int fontheight;
public:

  QSliderTime( TQSlider *ksl, TQWidget *parent = NULL, const char *name = NULL );

  int getFontHeight(void) {return fontheight;};

  TQSize sizeHint();
  TQSizePolicy sizePolicy();

private:

  virtual void paintEvent( TQPaintEvent * );  
  void drawTimeMarks(TQPainter *painter);

  char *formatMillisecs(int ms,char *tmp);
};

#endif

==> 3.5.13-core.tar: kdemultimedia/kmid/qslidertime.h <==
/**************************************************************************

    kslidertime.h  - A widget that displays time tags under a KSlider
    Copyright (C) 1997,98  Antonio Larrosa Jimenez

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

    Send comments and bug fixes to larrosa@kde.org
    or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain

***************************************************************************/
#ifndef _kslidertime_h_
#define _kslidertime_h_

#include <tqslider.h>

class TQWidget;

class QSliderTime : public TQWidget
{
  Q_OBJECT
  TQ_OBJECT
private:

  TQSlider *kslider;

int fontheight;
public:

  QSliderTime( TQSlider *ksl, TQWidget *parent = NULL, const char *name = NULL );

  int getFontHeight(void) {return fontheight;};

  TQSize tqsizeHint();
  TQSizePolicy sizePolicy();

private:

  virtual void paintEvent( TQPaintEvent * );  
  void drawTimeMarks(TQPainter *painter);

  char *formatMillisecs(int ms,char *tmp);
};

#endif
